@@ -6,5 +6,5 @@ void BigInt::checked3(BIGNUM *div, BIGNUM *rem,
     BNCTX ctx;
   
     if (BN_div(div, rem, &d_bn, &rhs.d_bn, ctx) != 1)
-        throw Errno("BigInt ") << insertable << op << " failed" << throwable;
+        throw Errno("BigInt ") << op << " failed";
 }
