@@ -1,6 +1,6 @@
 #include "bigint.ih"
 
-BigInt const BigInt::sqrModc(BigInt const &mod) const
+BigInt BigInt::sqrModc(BigInt const &mod) const
 {
     BigInt ret(*this);
     ret.sqrMod(mod);
