@@ -4,13 +4,10 @@ void Cidr::setCidr(istream &fin)
 {
     d_cidr.clear();
 
-    for_each(
-        istream_iterator<StringLine>(fin), istream_iterator<StringLine>(),
-        [this](string const &cidrPattern)
-        {
-            this->pushCidr(cidrPattern);
-        }
-    );
+    for (auto &cidrPattern: ranger(
+        istream_iterator<StringLine>(fin), istream_iterator<StringLine>())
+    )
+        pushCidr(cidrPattern);
 
     if (d_cidr.empty())
         throw Errno(1, "Cidr: ") << "no CIDR patterns found on "
