@@ -11,9 +11,9 @@ string DateTime::rfc3339() const
 
      timeStr(out) << ' ' << 
                     showpos << setw(3) << internal <<
-                            (d_displayZoneShift + d_dstShift) / 3600 << 
+                            d_displayZoneShift / 3600 << 
                     ':' << noshowpos << setw(2) << 
-                            abs(d_displayZoneShift + d_dstShift) % 3600 / 60;
+                            abs(d_displayZoneShift) % 3600 / 60;
 
     return out.str();
 }
