@@ -2,7 +2,8 @@
 
 void Glob::destroy()
 {
-    verify();       // in case no verify was explicitly called
+    if (!d_share)           // for the move-operations
+        return;
 
     if (!--d_share->users)
     {
