@@ -32,6 +32,6 @@ try
 }
 catch(Errno const &err)
 {
-    cout << err.what() << endl;
+    cout << err.why() << endl;
     return 1;
 }
