@@ -4,22 +4,20 @@ void Milter::initialize(string const &name, Milter &milter,
                         callback_set callbacks, flag_set flags)
 {
     if (s_mp)
-        throw Errno(1, "Milter::initialize()") << insertable <<
-            ": can't define multiple Milters" << throwable;
+        throw Errno(1, "Milter::initialize()") << 
+                       ": can't define multiple Milters";
 
     if (flags & ~ALL_FLAGS)
-        throw Errno(1, "Milter::initialize()") << insertable <<
-            ": invalid flag(s): " << hex << 
-                        (flags & ~ALL_FLAGS)<< dec << throwable;
+        throw Errno(1, "Milter::initialize()") << 
+            ": invalid flag(s): " << hex << (flags & ~ALL_FLAGS)<< dec;
 
     if (!callbacks)
-        throw Errno(1, "Milter::initialize()") << insertable <<
-            ": no callbacks requested" << throwable;
+        throw Errno(1, "Milter::initialize()") << ": no callbacks requested";
 
     if (callbacks & ~ALL_CALLBACKS)
-        throw Errno(1, "Milter::initialize()") << insertable <<
+        throw Errno(1, "Milter::initialize()") <<
             ": illegal callback(s) requested: " << hex << 
-                        (callbacks & ~ALL_CALLBACKS) << dec << throwable;
+                        (callbacks & ~ALL_CALLBACKS) << dec;
 
     struct smfiDesc descr = {const_cast<char *>(name.c_str()), 
                              SMFI_VERSION, flags, 0};
@@ -89,9 +87,8 @@ void Milter::initialize(string const &name, Milter &milter,
     }    
 
     if (smfi_register(descr) == MI_FAILURE)
-        throw Errno("Milter::initialize()") << insertable <<
-            ": defining Milter " << s_name << " failed" << 
-            throwable;
+        throw Errno("Milter::initialize()") << ": defining Milter " << 
+                                                        s_name << " failed";
 }
 
 
