@@ -5,9 +5,9 @@ Process::Process(iomode mode, ProcessType processType, size_t timeLimit,
 :
     d_command(command),
 
-    d_childCin(0),
-    d_childCout(0),
-    d_childCerr(0)
+    d_oChildIn(0),
+    d_iChildOut(0),
+    d_iChildErr(0)
 {
     initialize(timeLimit, mode, processType);
 }
