@@ -1,13 +1,5 @@
-/*
-                              selector.cc
-*/
-
 #include "selector.ih"
 
-using namespace std;
-using namespace FBB;
-
-
 int Selector::wait()
 {
     timeval t = d_alarm;
@@ -20,7 +12,8 @@ int Selector::wait()
     d_writeidx = 0;
     d_exceptidx = 0;
 
-    d_ret = select(d_max, &d_ret_read, &d_ret_write, &d_ret_except, &t);
+    d_ret = select(d_max, &d_ret_read, &d_ret_write, &d_ret_except, 
+                   t.tv_sec == -1 && t.tv_usec == -1 ? 0 : &t);
 
     if (d_ret < 0)
         throw Errno("Selector::wait()");
@@ -28,3 +21,5 @@ int Selector::wait()
     return d_ret;
 }
 
+
+
